AbstractDataListWidget | django_cradmin API Document

    import AbstractDataListWidget from 'django_cradmin/scripts/django_cradmin/widgets/AbstractDataListWidget.js'

public class | source

# AbstractDataListWidget

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → AbstractDataListWidget

#### Direct Subclass:

ApiDataListWidget, StaticDataListWidget

## Constructor Summary

Public Constructor
public | constructor(element: *, widgetInstanceId: *) |

## Member Summary

Public Members
public | logger: * |
public | signalHandlersInitialized: boolean |
public | state: * |

## Method Summary

Public Methods
public | afterInitializeAllWidgets() |
public | destroy() |
public | getDefaultConfig(): * |
public | makeRequestDataListOptions(overrideOptions: {}): * |
public | requestDataList() |
public | requestItemData(key: *) |
public | setState(stateChange: *, initial: boolean) |
public | useAfterInitializeAllWidgets(): boolean |

## Public Constructors

### public constructor(element: *, widgetInstanceId: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |
widgetInstanceId | * |  |

## Public Members

### public logger: * source

### public signalHandlersInitialized: boolean source

### public state: * source

## Public Methods

### public afterInitializeAllWidgets() source

### public destroy() source

### public getDefaultConfig(): * source

#### Return:

*

### public makeRequestDataListOptions(overrideOptions: {}): * source

#### Params:

Name | Type | Attribute | Description
overrideOptions | {} | optional default: {} |

#### Return:

*

### public requestDataList() source

### public requestItemData(key: *) source

#### Params:

Name | Type | Attribute | Description
key | * |  |

### public setState(stateChange: *, initial: boolean) source

#### Params:

Name | Type | Attribute | Description
stateChange | * |  |
initial | boolean | optional default: false |

### public useAfterInitializeAllWidgets(): boolean source

#### Return:

boolean